CREATE OR REPLACE FUNCTION insert_own_filter( filter_name VARCHAR, filter_query VARCHAR, user_name VARCHAR, parent_name VARCHAR )
RETURNS BOOLEAN AS $$
DECLARE
    user_id INT;
    par_id INT;
BEGIN
    user_id = (SELECT id FROM users WHERE name = user_name);
    par_id = (SELECT id FROM filters WHERE name = parent_name);
    IF ( user_id IS NOT NULL ) AND ( par_id IS NOT NULL ) THEN
	INSERT INTO filters(name, query, owner_id, parent_id) VALUES(filter_name, filter_query, user_id, par_id);
    ELSE
	RAISE EXCEPTION 'No such user or parent: % %', user_name, parent_name;
    END IF;

    RETURN TRUE;
EXCEPTION
    WHEN OTHERS THEN
	RAISE NOTICE 'Error number:%', SQLSTATE;
	RETURN FALSE;
END;
$$
LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION insert_global_filter( filter_name VARCHAR, filter_query VARCHAR, parent_name VARCHAR )
RETURNS BOOLEAN AS $$
DECLARE
    par_id INT;
BEGIN
    par_id = (SELECT id FROM filters WHERE name = parent_name);
    IF  par_id IS NOT NULL THEN
	INSERT INTO filters(name, query, parent_id) VALUES(filter_name, filter_query, par_id);
    ELSE
	RAISE EXCEPTION 'No such parent:%', parent_name;
    END IF;

    RETURN TRUE;
EXCEPTION
    WHEN OTHERS THEN
	RAISE NOTICE 'Error number:%', SQLSTATE;
	RETURN FALSE;
END;
$$
LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION get_parent( filter_name VARCHAR )
RETURNS SETOF own_filters AS $$
DECLARE
    par_id INT;
BEGIN
    par_id = (SELECT parent_id FROM filters WHERE name = filter_name);
    RETURN QUERY SELECT name, query FROM filters WHERE id = par_id;
    RETURN;
END;
$$
LANGUAGE plpgsql;

--ADD parent_id TO filters TO MAKE THE INHERITANCE
ALTER TABLE filters ADD parent_id INT DEFAULT NULL;
--UPDATE db VERSION
UPDATE service SET version = 4;
