--ADD NEW COLUMN TO TABLE settings
ALTER TABLE settings ADD create_fts_index BOOLEAN;
--SET create_fts_index TO TRUE
UPDATE settings SET create_fts_index = TRUE;
--UPDATE create_table_function TO MAKE FTS INDEX CREATION OPTIONAL
CREATE OR REPLACE FUNCTION create_table_function( tbl_date DATE, tbl_time TIME )
RETURNS BOOLEAN AS $$
DECLARE
    table_name CHAR(25);
    const_name CHAR(10);
    time_from TIMESTAMP;
    time_to TIMESTAMP;
BEGIN
    time_from := date_trunc( 'hour', tbl_date + tbl_time );
    time_to := time_from + INTERVAL '1 hour';
    table_name := 'messages_' || to_char(time_from, 'yyyy_mm_dd_hh24');
    const_name := 'const_' || to_char(time_from, 'hh24');
    EXECUTE ( 'CREATE TABLE ' || table_name ||  ' (LIKE messages INCLUDING DEFAULTS INCLUDING CONSTRAINTS)' );
    EXECUTE ( 'ALTER TABLE ' || table_name || ' ADD PRIMARY KEY (id)' );
    IF ( SELECT create_fts_index FROM settings ) THEN
		EXECUTE ( 'CREATE INDEX ' || table_name || '_key ON ' || table_name || ' USING gin( to_tsvector(''english'', fts) )');
	END IF;
    EXECUTE ( 'ALTER TABLE ' || table_name || ' ADD CONSTRAINT ' || const_name || ' CHECK ( rtime >= ' || quote_literal(time_from) || ' AND rtime < ' || quote_literal(time_to) || ' )' );
    EXECUTE ( 'ALTER TABLE ' || table_name || ' INHERIT messages' );
    EXECUTE ( 'ALTER TABLE ' || table_name || ' INHERIT rmessages' );
    IF ( register_table( table_name, get_location_mask( 'empty' ) ) = FALSE ) OR ( reinherit_function() = FALSE ) THEN
	RETURN FALSE;
    END IF;
    RETURN TRUE;
EXCEPTION
    WHEN OTHERS THEN
	RAISE NOTICE 'Error number:%', SQLSTATE;
	RETURN FALSE;
END;
$$
LANGUAGE plpgsql;
--UPDATE db VERSION
UPDATE service SET version = 8;
